@@ -359,7 +359,7 @@ setMethod(
     # not seeing userTags
     # Clear the futures that are resolved
     .onLinux <- .Platform$OS.type == "unix" && unname(Sys.info()["sysname"]) == "Linux" &&
-      !.isFALSE(getOption("reproducible.futurePlan"))
+      !isFALSE(getOption("reproducible.futurePlan"))
     if (.onLinux) {
       if (exists("futureEnv", envir = .reproEnv))
         hasFuture <- .requireNamespace("future",
@@ -731,7 +731,7 @@ getArtifact <- function(cacheRepo, shownCache, cacheId) {
 
 useDBI <- function() {
   ud <- getOption("reproducible.useDBI", TRUE)
-  if (.isFALSE(ud)) {
+  if (isFALSE(ud)) {
     stop("options('reproducible.useDBI') can only be TRUE in this and future versions of reproducible",
          call. = FALSE)
   }
