@@ -1,6 +1,5 @@
 test_that("prepInputs doesn't work (part 1)", {
   skip_on_cran()
-
   skip_on_ci()
 
   testInitOut <- testInit("raster", opts = list(
@@ -93,6 +92,8 @@ test_that("prepInputs doesn't work (part 1)", {
     "ecozones.shp",
     "ecozones.shx"
   )
+  oldPolyOption <- getOption("reproducible.polygonShortcut")
+  options("reproducible.polygonShortcut" = TRUE)
   warn <- suppressWarningsSpecific(
     falseWarnings = "attribute variables are assumed to be spatially constant", {
     shpEcozoneSm <- Cache(
@@ -106,8 +107,9 @@ test_that("prepInputs doesn't work (part 1)", {
       filename2 = "EcozoneFile.shp"
     )
   })
+  options("reproducible.polygonShortcut" = oldPolyOption)
   expect_true(is(shpEcozoneSm, "SpatialPolygons"))
-  expect_true(isTRUE(all.equal(extent(shpEcozoneSm), extent(StudyArea))))
+  expect_true(isTRUE(all.equal(extent(shpEcozoneSm), extent(StudyArea)))) ## TODO: fix #222
 
   unlink(dirname(ecozoneFilename), recursive = TRUE)
   # Test useCache = FALSE -- doesn't error and has no "loading from cache" or "loading from memoised"
@@ -181,7 +183,7 @@ test_that("prepInputs doesn't work (part 1)", {
   # #######################################
   # ### url, targetFile, archive     ######
   # #######################################
-  # # if wrapped with Cache, will be fast second time, very fast 3rd time (via memoised copy)
+  # # if wrapped with Cache, will be very fast second time (via memoised copy)
   # LCC2005_2 <- Cache(
   #   prepInputs,
   #   url = url,
@@ -218,10 +220,10 @@ test_that("prepInputs doesn't work (part 1)", {
   ######################################
   ## don't pass url -- use local copy of archive only
   ## use purge = TRUE to rm checksums file, rewrite it here
-  noisyOutput <- capture.output(
+  noisyOutput <- capture.output({
     shpEcozone <- prepInputs(destinationPath = dPath,
                              archive = file.path(dPath, "ecozone_shp.zip"), purge = TRUE)
-  )
+  })
   expect_true(is(shpEcozone, shapefileClassDefault))
 
   #######################################
@@ -459,13 +461,13 @@ test_that("preProcess doesn't work", {
   ###############################################################
   ##### url                                                 #####
   ###############################################################
-  noisyOutput <- capture.output(
+  noisyOutput <- capture.output({
     mess <- capture_messages({
-    warns <- capture_warnings({
-      test <- prepInputs(url = urlTif1, destinationPath = tmpdir)
+      warns <- capture_warnings({
+        test <- prepInputs(url = urlTif1, destinationPath = tmpdir)
+      })
     })
   })
-  )
   runTest("1_2_5_6_7_10_13", "Raster", 1, mess, expectedMess = expectedMessage,
           filePattern = "DEM", tmpdir = tmpdir, test = test)
 
@@ -480,13 +482,13 @@ test_that("preProcess doesn't work", {
   unlink(dir(tmpdir, full.names = TRUE))
 
   # url is an archive on googledrive -- can get file.info from remote -- so can do checksums
-  noisyOutput <- capture.output(
+  noisyOutput <- capture.output({
     mess <- capture_messages({
       warns <- capture_warnings({
         test <- prepInputs(url = urlShapefiles1Zip, destinationPath = tmpdir)
       })
     })
-  )
+  })
 
   runTest("1_2_3_4_5_6_7_10_12_13", shapefileClassDefault, 5, mess, expectedMess = expectedMessage,
           filePattern = "Shapefile", tmpdir = tmpdir, test = test)
@@ -504,13 +506,13 @@ test_that("preProcess doesn't work", {
   ################################################################
   ###### url, targetFile                                     #####
   ################################################################
-  noisyOutput <- capture.output(
+  noisyOutput <- capture.output({
     mess <- capture_messages({
-    warns <- capture_warnings({
-      test <- prepInputs(url = urlTif1, targetFile = basename(urlTif1), destinationPath = tmpdir)
+      warns <- capture_warnings({
+        test <- prepInputs(url = urlTif1, targetFile = basename(urlTif1), destinationPath = tmpdir)
+      })
     })
   })
-  )
   runTest("1_2_5_6_7_13", "Raster", 1, mess, expectedMess = expectedMessage,
           filePattern = "DEM", tmpdir = tmpdir, test = test)
 
@@ -548,13 +550,13 @@ test_that("preProcess doesn't work", {
   ################################################################
   ###### url, alsoExtract                                    #####
   ################################################################
-  noisyOutput <- capture.output(
+  noisyOutput <- capture.output({
     mess <- capture_messages({
-    warns <- capture_warnings({
-      test <- prepInputs(url = urlTif1, alsoExtract = "DEM.tif", destinationPath = tmpdir)
+      warns <- capture_warnings({
+        test <- prepInputs(url = urlTif1, alsoExtract = "DEM.tif", destinationPath = tmpdir)
+      })
     })
   })
-  )
   runTest("1_2_5_6_7_10_13", "Raster", 1, mess, expectedMess = expectedMessage,
           filePattern = "DEM", tmpdir = tmpdir, test = test)
 
@@ -604,17 +606,17 @@ test_that("preProcess doesn't work", {
   ################################################################
   # url is an archive on googledrive -- here, zip has 2 Shapefile filesets -- Shapefile1* and Shapefile2*
   #   should extract all
-  noisyOutput <- capture.output(
+  noisyOutput <- capture.output({
     mess <- capture_messages({
-    warns <- capture_warnings({
-      test <- prepInputs(
-        url = urlShapefilesZip,
-        archive = "Shapefiles1.zip",
-        destinationPath = tmpdir
-      )
+      warns <- capture_warnings({
+        test <- prepInputs(
+          url = urlShapefilesZip,
+          archive = "Shapefiles1.zip",
+          destinationPath = tmpdir
+        )
+      })
     })
   })
-  )
   runTest("1_2_3_4_5_6_7_10_12_13", shapefileClassDefault, 9, mess, expectedMess = expectedMessage,
           filePattern = "Shapefile", tmpdir = tmpdir, test = test)
 
@@ -709,18 +711,18 @@ test_that("preProcess doesn't work", {
   })
   runTest("1_2_3_4_5_6_7_13", shapefileClassDefault, 5, mess, expectedMess = expectedMessage,
           filePattern = "Shapefile", tmpdir = tmpdir, test = test)
-  noisyOutput <- capture.output(
+  noisyOutput <- capture.output({
     mess <- capture_messages({
-    warns <- capture_warnings({
-      test <- prepInputs(
-        url = urlTif1,
-        targetFile = "DEM.tif",
-        alsoExtract = c("DEM.tif"),
-        destinationPath = tmpdir
-      )
+      warns <- capture_warnings({
+        test <- prepInputs(
+          url = urlTif1,
+          targetFile = "DEM.tif",
+          alsoExtract = c("DEM.tif"),
+          destinationPath = tmpdir
+        )
+      })
     })
   })
-  )
   runTest("1_2_5_6_7_13", "Raster", 1, mess, expectedMess = expectedMessage,
           filePattern = "DEM", tmpdir = tmpdir, test = test)
   unlink(dir(tmpdir, full.names = TRUE))
@@ -1136,95 +1138,96 @@ test_that("preProcess doesn't work", {
 
 test_that("prepInputs doesn't work (part 2)", {
   skip_on_cran()
+  skip_if_not(getRversion() > "3.3.0")
 
-  if (getRversion() > "3.3.0") {
-    testInitOut <- testInit(c("RCurl", "raster"), opts = list(
-      "rasterTmpDir" = tempdir2(rndstr(1,6)),
-      "reproducible.overwrite" = TRUE,
-      "reproducible.inputPaths" = NULL
-    ), needGoogle = TRUE)
-    on.exit({
-      testOnExit(testInitOut)
-    }, add = TRUE)
+  testInitOut <- testInit(c("RCurl", "raster"), opts = list(
+    "rasterTmpDir" = tempdir2(rndstr(1,6)),
+    "reproducible.overwrite" = TRUE,
+    "reproducible.inputPaths" = NULL
+  ), needGoogle = TRUE)
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
 
-    coords <- structure(c(6, 6.1, 6.2, 6.15, 6, 49.5, 49.7, 49.8, 49.6, 49.5), .Dim = c(5L, 2L))
-    Sr1 <- Polygon(coords)
-    Srs1 <- Polygons(list(Sr1), "s1")
-    StudyArea <- SpatialPolygons(list(Srs1), 1L)
-    crs(StudyArea) <- crsToUse
+  coords <- structure(c(6, 6.1, 6.2, 6.15, 6, 49.5, 49.7, 49.8, 49.6, 49.5), .Dim = c(5L, 2L))
+  Sr1 <- Polygon(coords)
+  Srs1 <- Polygons(list(Sr1), "s1")
+  StudyArea <- SpatialPolygons(list(Srs1), 1L)
+  crs(StudyArea) <- crsToUse
 
-    if (requireNamespace("RCurl")) {
-      if (RCurl::url.exists("https://biogeo.ucdavis.edu/data/gadm3.6/Rsp/gadm36_LUX_0_sp.rds",
-                     timeout = 1)) {
-        noisyOutput <- capture.output(type = "message", {
-          mess1 <- capture_messages({
-            test1 <- prepInputs(
-              #targetFile = "GADM_2.8_LUX_adm0.rds", # looks like GADM has changed their API
-              targetFile = targetFileLuxRDS,
-              #destinationPath = ".",
-              dlFun = getDataFn, name = "GADM", country = "LUX", level = 0,
-              #dlFun = "raster::getData", name = "GADM", country = "LUX", level = 0,
-              path = tmpdir)
-          })
+  if (requireNamespace("RCurl")) {
+    if (RCurl::url.exists("https://biogeo.ucdavis.edu/data/gadm3.6/Rsp/gadm36_LUX_0_sp.rds",
+                   timeout = 1)) {
+      noisyOutput <- capture.output(type = "message", {
+        mess1 <- capture_messages({
+          test1 <- prepInputs(
+            #targetFile = "GADM_2.8_LUX_adm0.rds", # looks like GADM has changed their API
+            targetFile = targetFileLuxRDS,
+            #destinationPath = ".",
+            dlFun = getDataFn, name = "GADM", country = "LUX", level = 0,
+            #dlFun = "raster::getData", name = "GADM", country = "LUX", level = 0,
+            path = tmpdir)
         })
-        mess2 <- capture_messages({
-          test2 <- prepInputs(targetFile = targetFileLuxRDS,
+      })
+      mess2 <- capture_messages({
+        test2 <- prepInputs(targetFile = targetFileLuxRDS,
+                            dlFun = getDataFn, name = "GADM", country = "LUX", level = 0,
+                            path = tmpdir)
+      })
+
+      runTest("1_2_5_6_13", "SpatialPolygonsDataFrame", 1, mess1, expectedMess = expectedMessage,
+              filePattern = targetFileLuxRDS, tmpdir = tmpdir, test = test1)
+      runTest("1_2_5_6_8", "SpatialPolygonsDataFrame", 1, mess2, expectedMess = expectedMessage,
+              filePattern = targetFileLuxRDS, tmpdir = tmpdir, test = test1)
+      mess2 <- capture_messages({
+        warn <- capture_warnings({
+          test3 <- prepInputs(targetFile = targetFileLuxRDS,
                               dlFun = getDataFn, name = "GADM", country = "LUX", level = 0,
-                              path = tmpdir)
+                              path = tmpdir, filename2 = "gadm36_LUX_0_sp.rds.shp", studyArea = StudyArea)
         })
+      })
+      # Why is no longer "although coordinates are longitude"?
+      runTest("1_2_5_6_8", "SpatialPolygonsDataFrame", 5, mess2, expectedMess = expectedMessage,
+              filePattern = targetFileLuxRDS, tmpdir = tmpdir,
+              test = test3)
 
-        runTest("1_2_5_6_13", "SpatialPolygonsDataFrame", 1, mess1, expectedMess = expectedMessage,
-                filePattern = targetFileLuxRDS, tmpdir = tmpdir, test = test1)
-        runTest("1_2_5_6_8", "SpatialPolygonsDataFrame", 1, mess2, expectedMess = expectedMessage,
-                filePattern = targetFileLuxRDS, tmpdir = tmpdir, test = test1)
+      testOnExit(testInitOut)
+      testInitOut <- testInit("raster", opts = list("reproducible.inputPaths" = NULL,
+                                                    "reproducible.overwrite" = TRUE),
+                              needGoogle = TRUE)
+      noisyOutput <- capture.output(type = "message", {
         mess2 <- capture_messages({
           warn <- capture_warnings({
-            test3 <- prepInputs(targetFile = targetFileLuxRDS,
-                                dlFun = getDataFn, name = "GADM", country = "LUX", level = 0,
-                                path = tmpdir, filename2 = "gadm36_LUX_0_sp.rds.shp", studyArea = StudyArea)
+            test3 <- prepInputs(targetFile = targetFileLuxRDS, dlFun = getDataFn, name = "GADM",
+                                country = "LUX", level = 0, path = tmpdir,
+                                filename2 = "gadm36_LUX_0_sp.rds.shp", studyArea = StudyArea)
           })
         })
-        runTest("1_2_5_6_8_14", "SpatialPolygonsDataFrame", 5, mess2, expectedMess = expectedMessage,
-                filePattern = targetFileLuxRDS, tmpdir = tmpdir,
-                test = test3)
+      })
+      runTest("1_2_5_6_13", "SpatialPolygonsDataFrame", 5, mess2, expectedMess = expectedMessage,
+              filePattern = targetFileLuxRDS, tmpdir = tmpdir,
+              test = test3)
 
-        testOnExit(testInitOut)
-        testInitOut <- testInit("raster", opts = list("reproducible.inputPaths" = NULL,
-                                                      "reproducible.overwrite" = TRUE),
-                                needGoogle = TRUE)
-        noisyOutput <- capture.output(type = "message", {
-          mess2 <- capture_messages({
-            warn <- capture_warnings({
-              test3 <- prepInputs(targetFile = targetFileLuxRDS, dlFun = getDataFn, name = "GADM",
-                                  country = "LUX", level = 0, path = tmpdir,
-                                  filename2 = "gadm36_LUX_0_sp.rds.shp", studyArea = StudyArea)
-            })
-          })
-        })
-        runTest("1_2_5_6_13_14", "SpatialPolygonsDataFrame", 5, mess2, expectedMess = expectedMessage,
-                filePattern = targetFileLuxRDS, tmpdir = tmpdir,
-                test = test3)
+      runTest("1_2_3_4", "SpatialPolygonsDataFrame", 5, mess2,
+              expectedMess = expectedMessagePostProcess,
+              filePattern = targetFileLuxRDS, tmpdir = tmpdir, test = test3)
 
-        runTest("1_2_4_6", "SpatialPolygonsDataFrame", 5, mess2,
-                expectedMess = expectedMessagePostProcess,
-                filePattern = targetFileLuxRDS, tmpdir = tmpdir, test = test3)
-
-        testOnExit(testInitOut)
-        testInitOut <- testInit("raster", opts = list("reproducible.overwrite" = TRUE,
-                                                      "reproducible.inputPaths" = NULL),
-                                needGoogle = TRUE)
-      }
+      testOnExit(testInitOut)
+      testInitOut <- testInit("raster", opts = list("reproducible.overwrite" = TRUE,
+                                                    "reproducible.inputPaths" = NULL),
+                              needGoogle = TRUE)
     }
-    # Add a study area to Crop and Mask to
-    # Create a "study area"
-    coords <- structure(c(6, 6.1, 6.2, 6.15, 6, 49.5, 49.7, 49.8, 49.6, 49.5), .Dim = c(5L, 2L))
-    Sr1 <- Polygon(coords)
-    Srs1 <- Polygons(list(Sr1), "s1")
-    StudyArea <- SpatialPolygons(list(Srs1), 1L)
-    crs(StudyArea) <- crsToUse
+  }
+  # Add a study area to Crop and Mask to
+  # Create a "study area"
+  coords <- structure(c(6, 6.1, 6.2, 6.15, 6, 49.5, 49.7, 49.8, 49.6, 49.5), .Dim = c(5L, 2L))
+  Sr1 <- Polygon(coords)
+  Srs1 <- Polygons(list(Sr1), "s1")
+  StudyArea <- SpatialPolygons(list(Srs1), 1L)
+  crs(StudyArea) <- crsToUse
 
-    noisyOutput <- capture.output(
-      mess1 <- capture_messages({
+  noisyOutput <- capture.output({
+    mess1 <- capture_messages({
       test <- prepInputs(
         targetFile = "DEM.tif",
         url = urlTif1,
@@ -1232,34 +1235,33 @@ test_that("prepInputs doesn't work (part 2)", {
         useCache = TRUE
       )
     })
-    )
-    runTest("1_2_5_6_7_13", "Raster", 1, mess1, expectedMess = expectedMessage,
-            filePattern = "DEM", tmpdir = tmpdir, test = test)
+  })
+  runTest("1_2_5_6_7_13", "Raster", 1, mess1, expectedMess = expectedMessage,
+          filePattern = "DEM", tmpdir = tmpdir, test = test)
 
-    if (interactive()) {
-      testOnExit(testInitOut)
-      testInitOut <- testInit("raster", opts = list("reproducible.inputPaths" = NULL,
-                                                    "reproducible.overwrite" = TRUE),
-                              needGoogle = TRUE)
-      opts <- options("reproducible.cachePath" = tmpCache)
-      on.exit({
-        options(opts)
-      }, add = TRUE)
+  if (interactive()) {
+    testOnExit(testInitOut)
+    testInitOut <- testInit("raster", opts = list("reproducible.inputPaths" = NULL,
+                                                  "reproducible.overwrite" = TRUE),
+                            needGoogle = TRUE)
+    opts <- options("reproducible.cachePath" = tmpCache)
+    on.exit({
+      options(opts)
+    }, add = TRUE)
 
-      mess2 <- capture_messages({
-        warn <- capture_warnings({
-          test3 <- prepInputs(
-            url = "https://drive.google.com/file/d/1zkdGyqkssmx14B9wotOqlK7iQt3aOSHC/view?usp=sharing", #nolint
-            studyArea = StudyArea,
-            destinationPath = tmpdir,
-            fun = "base::readRDS"
-          )
-        })
+    mess2 <- capture_messages({
+      warn <- capture_warnings({
+        test3 <- prepInputs(
+          url = "https://drive.google.com/file/d/1zkdGyqkssmx14B9wotOqlK7iQt3aOSHC/view?usp=sharing", #nolint
+          studyArea = StudyArea,
+          destinationPath = tmpdir,
+          fun = "base::readRDS"
+        )
       })
-      runTest("1_2_3_4_6", "SpatialPolygonsDataFrame", 1, mess2,
-              expectedMess = expectedMessagePostProcess,
-              filePattern = "GADM_2.8_LUX_adm0.rds$", tmpdir = tmpdir, test = test3)
-    }
+    })
+    runTest("1_2_3_4_6", "SpatialPolygonsDataFrame", 1, mess2,
+            expectedMess = expectedMessagePostProcess,
+            filePattern = "GADM_2.8_LUX_adm0.rds$", tmpdir = tmpdir, test = test3)
   }
 })
 
@@ -1462,16 +1464,16 @@ test_that("lightweight tests for code coverage", {
     file.remove(file.path(tmpdir, "ecozone_shp.zip"))
     checkSums <- Checksums(path = tmpdir)
 
-
-
     noisyOutput <- capture.output(
-      expect_error(downloadFile(url = url,
-                                neededFiles = c("ecozones.dbf", "ecozones.prj", "ecozones.sbn", "ecozones.sbx",
-                                                "ecozones.shp", "ecozones.shx"),
-                                checkSums = checkSums,
-                                targetFile = "ecozones.shp",
-                                archive = "ecozone_shp.zip", needChecksums = TRUE, quick = FALSE,
-                                destinationPath = tmpdir, checksumFile = checkSumFilePath))
+      expect_error(
+        downloadFile(url = url,
+                     neededFiles = c("ecozones.dbf", "ecozones.prj", "ecozones.sbn", "ecozones.sbx",
+                                     "ecozones.shp", "ecozones.shx"),
+                     checkSums = checkSums,
+                     targetFile = "ecozones.shp",
+                     archive = "ecozone_shp.zip", needChecksums = TRUE, quick = FALSE,
+                     destinationPath = tmpdir, checksumFile = checkSumFilePath)
+      )
     )
 
     ## postProcess.default
@@ -1638,9 +1640,8 @@ test_that("options inputPaths", {
     options("reproducible.inputPaths" = NULL)
     options("reproducible.inputPathsRecursive" = FALSE)
 
-    noisyOutput <- capture.output(
-      noisyOutput <- capture.output(
-        type = "message",
+    noisyOutput <- capture.output({
+      noisyOutput <- capture.output(type = "message", {
         mess1 <- capture_messages({
           test1 <- prepInputs(destinationPath = tmpdir,
                               url = if (!useGADM) url2 else f$url,
@@ -1651,11 +1652,12 @@ test_that("options inputPaths", {
                               level = if (useGADM) 0 else NULL,
                               path = if (useGADM) tmpdir else NULL)
         })
-      ))
+      })
+    })
     # Use inputPaths -- should do a link to tmpCache (the destinationPath)
     options("reproducible.inputPaths" = tmpdir)
     options("reproducible.inputPathsRecursive" = FALSE)
-    noisyOutput <- capture.output(
+    noisyOutput <- capture.output({
       mess1 <- capture_messages({
         test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
                             targetFile = if (useGADM) theFile else f$targetFile,
@@ -1666,7 +1668,7 @@ test_that("options inputPaths", {
                             path = if (useGADM) tmpdir else NULL,
                             destinationPath = tmpCache)
       })
-    )
+    })
     expect_true(sum(grepl(paste0(hardlinkMessagePrefixForGrep, ": ", tmpCache), mess1)) == 1)
 
     # Now two folders - file not in destinationPath, not in 1st inputPaths, but yes 2nd
@@ -1674,7 +1676,7 @@ test_that("options inputPaths", {
     options("reproducible.inputPaths" = c(tmpdir, tmpCache))
     file.remove(file.path(tmpdir, theFile))
     tmpdir3 <- file.path(tmpCache, "test")
-    noisyOutput <- capture.output(
+    noisyOutput <- capture.output({
       mess1 <- capture_messages({
         test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
                             targetFile = if (useGADM) theFile else f$targetFile,
@@ -1683,11 +1685,9 @@ test_that("options inputPaths", {
                             country = if (useGADM) "LUX" else NULL,
                             level = if (useGADM) 0 else NULL,
                             path = if (useGADM) tmpdir else NULL,
-                            destinationPath = tmpdir3
-        )
-
+                            destinationPath = tmpdir3)
       })
-    )
+    })
     expect_true(sum(grepl(paste0(hardlinkMessagePrefixForGrep, ": ", tmpdir3), mess1)) == 1)
 
     #  should copy from 2nd directory (tmpCache) because it is removed in the lower
@@ -1696,20 +1696,18 @@ test_that("options inputPaths", {
     options("reproducible.inputPathsRecursive" = TRUE)
     file.remove(file.path(tmpCache, theFile))
     tmpdir1 <- file.path(tmpCache, "test1")
-    noisyOutput <- capture.output(
+    noisyOutput <- capture.output({
       mess1 <- capture_messages({
         test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
                             targetFile = if (useGADM) theFile else f$targetFile,
                             dlFun = if (useGADM) getDataFn else NULL,
                             name = if (useGADM) "GADM" else NULL,
                             country = if (useGADM) "LUX" else NULL,
-
                             level = if (useGADM) 0 else NULL,
                             path = if (useGADM) tmpdir else NULL,
-                            destinationPath = tmpdir1
-        )
+                            destinationPath = tmpdir1)
       })
-    )
+    })
     expect_true(sum(grepl(paste0(hardlinkMessagePrefixForGrep, ": ", file.path(tmpdir1, theFile)), mess1)) == 1)
     expect_true(sum(grepl(paste0("",whPointsToMessForGrep," ", file.path(tmpdir3, theFile)), mess1)) == 1)
     expect_true(sum(basename(dir(file.path(tmpdir), recursive = TRUE)) %in% theFile) == 2)
@@ -1721,20 +1719,20 @@ test_that("options inputPaths", {
                                         "reproducible.inputPathsRecursive" = FALSE))
     options("reproducible.inputPaths" = tmpdir)
     tmpdir2 <- file.path(tmpdir, rndstr(1,5))
-    noisyOutput <- capture.output(
-      noisyOutput <- capture.output(type = "message",
-                                    mess1 <- capture_messages({
-                                      test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
-                                                          targetFile = if (useGADM) theFile else f$targetFile,
-                                                          dlFun = if (useGADM) getDataFn else NULL,
-                                                          name = if (useGADM) "GADM" else NULL,
-                                                          country = if (useGADM) "LUX" else NULL,
-                                                          level = if (useGADM) 0 else NULL,
-                                                          path = if (useGADM) tmpdir else NULL,
-                                                          destinationPath = tmpdir2
-                                      )
-                                    })
-      ))
+    noisyOutput <- capture.output({
+      noisyOutput <- capture.output(type = "message", {
+        mess1 <- capture_messages({
+          test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
+                              targetFile = if (useGADM) theFile else f$targetFile,
+                              dlFun = if (useGADM) getDataFn else NULL,
+                              name = if (useGADM) "GADM" else NULL,
+                              country = if (useGADM) "LUX" else NULL,
+                              level = if (useGADM) 0 else NULL,
+                              path = if (useGADM) tmpdir else NULL,
+                              destinationPath = tmpdir2)
+          })
+        })
+      })
 
     # Must remove the link that happens during downloading to a .tempPath
     test10 <- grep(hardlinkMessagePrefixForGrep, mess1, value = TRUE)
@@ -1746,8 +1744,7 @@ test_that("options inputPaths", {
     expect_false(file.exists(file.path(tmpdir2, theFile))) # FALSE -- confirm previous line
     expect_true(file.exists(file.path(tmpdir, theFile))) # TRUE b/c is in getOption('reproducible.inputPaths')
     tmpdir2 <- file.path(tmpdir, rndstr(1, 5))
-    noisyOutput <- capture.output(
-
+    noisyOutput <- capture.output({
       mess1 <- capture_messages({
         test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
                             targetFile = if (useGADM) theFile else f$targetFile,
@@ -1756,10 +1753,9 @@ test_that("options inputPaths", {
                             country = if (useGADM) "LUX" else NULL,
                             level = if (useGADM) 0 else NULL,
                             path = if (useGADM) tmpdir else NULL,
-                            destinationPath = tmpdir2
-        )
+                            destinationPath = tmpdir2)
       })
-    )
+    })
     expect_true(sum(grepl(hardlinkMessagePrefixForGrep, mess1)) == 1) # used a linked version
     expect_true(sum(grepl(paste0("Hardlinked.*",basename(tmpdir2)), mess1)) == 1) # it is now in tmpdir2, i.e., the destinationPath
 
@@ -1767,8 +1763,7 @@ test_that("options inputPaths", {
     unlink(file.path(tmpdir, theFile))
     expect_false(file.exists(file.path(tmpdir, theFile))) # FALSE -- confirm previous line
     expect_true(file.exists(file.path(tmpdir2, theFile))) # TRUE b/c is in getOption('reproducible.inputPaths')
-    noisyOutput <- capture.output(
-
+    noisyOutput <- capture.output({
       mess1 <- capture_messages({
         test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
                             targetFile = if (useGADM) theFile else f$targetFile,
@@ -1777,10 +1772,9 @@ test_that("options inputPaths", {
                             country = if (useGADM) "LUX" else NULL,
                             level = if (useGADM) 0 else NULL,
                             path = if (useGADM) tmpdir else NULL,
-                            destinationPath = tmpdir2
-        )
+                            destinationPath = tmpdir2)
       })
-    )
+    })
     expect_true(sum(grepl(hardlinkMessagePrefixForGrep, mess1)) == 1) # used a linked version
     expect_true(sum(grepl(paste0("Hardlinked.*",basename(tmpdir2)), mess1)) == 1) # it is now in tmpdir2, i.e., the destinationPath
 
@@ -1790,21 +1784,20 @@ test_that("options inputPaths", {
     expect_false(file.exists(file.path(tmpdir, theFile))) # FALSE -- confirm previous line
     expect_false(file.exists(file.path(tmpdir2, theFile))) # TRUE b/c is in getOption('reproducible.inputPaths')
     options("reproducible.inputPaths" = tmpdir)
-    noisyOutput <- capture.output(
-      noisyOutput <- capture.output(type = "message",
-                                    mess1 <- capture_messages({
-                                      test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
-                                                          targetFile = if (useGADM) theFile else f$targetFile,
-                                                          dlFun = if (useGADM) getDataFn else NULL,
-                                                          name = if (useGADM) "GADM" else NULL,
-                                                          country = if (useGADM) "LUX" else NULL,
-                                                          level = if (useGADM) 0 else NULL,
-                                                          path = if (useGADM) tmpdir else NULL,
-                                                          destinationPath = tmpdir
-                                      )
-                                    })
-      )
-    )
+    noisyOutput <- capture.output({
+      noisyOutput <- capture.output(type = "message", {
+        mess1 <- capture_messages({
+          test1 <- prepInputs(url = if (!useGADM) url2 else f$url,
+                              targetFile = if (useGADM) theFile else f$targetFile,
+                              dlFun = if (useGADM) getDataFn else NULL,
+                              name = if (useGADM) "GADM" else NULL,
+                              country = if (useGADM) "LUX" else NULL,
+                              level = if (useGADM) 0 else NULL,
+                              path = if (useGADM) tmpdir else NULL,
+                              destinationPath = tmpdir)
+        })
+      })
+    })
     expect_true(is(test1, "spatialClasses"))
     test11 <- grep(hardlinkMessagePrefixForGrep, mess1, value = TRUE)
     test11 <- grep(tmpdir, test11, invert = TRUE)
@@ -1868,9 +1861,11 @@ test_that("rasters aren't properly resampled", {
   expect_true(dataType(out) == "INT2U")
 
   # Test bilinear --> but keeps integer if it is integer
-  suppressWarnings(out2 <- prepInputs(targetFile = tiftemp1, rasterToMatch = raster(tiftemp2),
-                     destinationPath = dirname(tiftemp1), method = "bilinear",
-                     filename2 = tempfile(tmpdir = tmpdir, fileext = ".tif"))) # about "raster layer has integer values"
+  suppressWarnings({
+    out2 <- prepInputs(targetFile = tiftemp1, rasterToMatch = raster(tiftemp2),
+                       destinationPath = dirname(tiftemp1), method = "bilinear",
+                       filename2 = tempfile(tmpdir = tmpdir, fileext = ".tif"))
+  }) # about "raster layer has integer values"
   expect_true(dataType(out2) %in% c("INT2S", "INT2U")) # because of "bilinear", it can become negative
 
   rrr1 <- raster(extent(0, 20, 0, 20), res = 1, vals = runif(400, 0, 1))
@@ -1912,14 +1907,10 @@ test_that("rasters aren't properly resampled", {
                      filename2 = c(tempfile(tmpdir = tmpdir, fileext = ".grd"), tempfile(tmpdir = tmpdir, fileext = ".grd")))
   expect_true(is(out4, "RasterStack"))
   expect_true(identical(length(Filenames(out4)), 4L))
-
 })
 
 test_that("System call gdal works", {
   skip_on_cran()
-  hasGDAL <- findGDAL()
-  if (!isTRUE(hasGDAL))
-    skip("no GDAL installation found")
 
   testInitOut <- testInit("raster")
   on.exit({
@@ -1954,11 +1945,8 @@ test_that("System call gdal works", {
   on.exit(raster::rasterOptions(todisk = FALSE))
 })
 
-test_that("System call gdal works using multicores for both projecting and masking", {
+test_that("gdalUtilities works using multicores for both projecting and masking", {
   skip_on_cran()
-  hasGDAL <- findGDAL()
-  if (!isTRUE(hasGDAL))
-    skip("no GDAL installation found")
 
   testInitOut <- testInit("raster")
   on.exit({
@@ -2009,9 +1997,6 @@ test_that("System call gdal works using multicores for both projecting and maski
 
 test_that("System call gdal will make the rasters match for rasterStack", {
   skip_on_cran()
-  hasGDAL <- findGDAL()
-  if (!isTRUE(hasGDAL))
-    skip("no GDAL installation found")
 
   testInitOut <- testInit("raster")
   on.exit({
@@ -2045,4 +2030,3 @@ test_that("System call gdal will make the rasters match for rasterStack", {
 
   on.exit(raster::rasterOptions(todisk = FALSE))
 })
-
